AsyncView

Struct AsyncView 

pub struct AsyncView<'a, T, E> { /* private fields */ }
A standardized widget that exhaustively handles the Idle, Pending, Failed, and Finished states of a data fetch.

Use this to wrap the core visual components of your app that rely on external data.

Implementations

Source

impl<'a, T, E> AsyncView<'a, T, E>

pub fn new(bind: &'a mut Bind<T, E>) -> Self

Constructs a new AsyncView.

pub fn loading_text(self, text: impl Into<String>) -> Self

Sets the text to display below the spinner when the fetch is pending.

pub fn error_retry_text(self, text: impl Into<String>) -> Self

Sets the text to display on the retry button when the fetch fails.

pub const fn state_layout(self, layout: StateLayout) -> Self

Configures the layout strategy for the intermediate loading and error states.

pub fn show<Fut, R>( self, ui: &mut Ui, fetch: impl FnOnce() -> Fut, on_ok: impl FnOnce(&mut Ui, &T) -> R, ) -> Option<R>
where Fut: Future<Output = Result<T, E>> + MaybeSend + 'static, T: MaybeSend + 'static, E: Debug + MaybeSend + 'static,

Runs the state machine. If data is successfully loaded, it invokes on_ok to let you render your successful data.

Returns

Some(R) if the data is available and successfully rendered, otherwise None.