macro_rules! run_once {
{ $($tokens:tt)* } => { ... };
}Expand description
A macro to run initialization code only once, even in the presence of multiple threads.
Returns true if the code was executed in this call, false otherwise.
macro_rules! run_once {
{ $($tokens:tt)* } => { ... };
}A macro to run initialization code only once, even in the presence of multiple threads.
Returns true if the code was executed in this call, false otherwise.